"""SPDX License List as a dictionary."""

from __future__ import annotations

from typing import NamedTuple


class License(NamedTuple):
    """Data for a license."""

    id: str
    name: str
    deprecated_id: bool
    fsf_libre: bool
    osi_approved: bool


LICENSES: dict[str, License] = {
    "0BSD": License(
        id="0BSD",
        name="BSD Zero Clause License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "AAL": License(
        id="AAL",
        name="Attribution Assurance License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Abstyles": License(
        id="Abstyles",
        name="Abstyles License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "AdaCore-doc": License(
        id="AdaCore-doc",
        name="AdaCore Doc License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Adobe-2006": License(
        id="Adobe-2006",
        name="Adobe Systems Incorporated Source Code License Agreement",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Adobe-Display-PostScript": License(
        id="Adobe-Display-PostScript",
        name="Adobe Display PostScript License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Adobe-Glyph": License(
        id="Adobe-Glyph",
        name="Adobe Glyph List License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Adobe-Utopia": License(
        id="Adobe-Utopia",
        name="Adobe Utopia Font License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ADSL": License(
        id="ADSL",
        name="Amazon Digital Services License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "AFL-1.1": License(
        id="AFL-1.1",
        name="Academic Free License v1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "AFL-1.2": License(
        id="AFL-1.2",
        name="Academic Free License v1.2",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "AFL-2.0": License(
        id="AFL-2.0",
        name="Academic Free License v2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "AFL-2.1": License(
        id="AFL-2.1",
        name="Academic Free License v2.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "AFL-3.0": License(
        id="AFL-3.0",
        name="Academic Free License v3.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "Afmparse": License(
        id="Afmparse",
        name="Afmparse License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "AGPL-1.0": License(
        id="AGPL-1.0",
        name="Affero General Public License v1.0",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=False,
    ),
    "AGPL-1.0-only": License(
        id="AGPL-1.0-only",
        name="Affero General Public License v1.0 only",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "AGPL-1.0-or-later": License(
        id="AGPL-1.0-or-later",
        name="Affero General Public License v1.0 or later",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "AGPL-3.0": License(
        id="AGPL-3.0",
        name="GNU Affero General Public License v3.0",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=True,
    ),
    "AGPL-3.0-only": License(
        id="AGPL-3.0-only",
        name="GNU Affero General Public License v3.0 only",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "AGPL-3.0-or-later": License(
        id="AGPL-3.0-or-later",
        name="GNU Affero General Public License v3.0 or later",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "Aladdin": License(
        id="Aladdin",
        name="Aladdin Free Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "AMDPLPA": License(
        id="AMDPLPA",
        name="AMD's plpa_map.c License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "AML": License(
        id="AML",
        name="Apple MIT License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "AML-glslang": License(
        id="AML-glslang",
        name="AML glslang variant License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "AMPAS": License(
        id="AMPAS",
        name="Academy of Motion Picture Arts and Sciences BSD",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ANTLR-PD": License(
        id="ANTLR-PD",
        name="ANTLR Software Rights Notice",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ANTLR-PD-fallback": License(
        id="ANTLR-PD-fallback",
        name="ANTLR Software Rights Notice with license fallback",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Apache-1.0": License(
        id="Apache-1.0",
        name="Apache License 1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Apache-1.1": License(
        id="Apache-1.1",
        name="Apache License 1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "Apache-2.0": License(
        id="Apache-2.0",
        name="Apache License 2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "APAFML": License(
        id="APAFML",
        name="Adobe Postscript AFM License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "APL-1.0": License(
        id="APL-1.0",
        name="Adaptive Public License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "App-s2p": License(
        id="App-s2p",
        name="App::s2p License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "APSL-1.0": License(
        id="APSL-1.0",
        name="Apple Public Source License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "APSL-1.1": License(
        id="APSL-1.1",
        name="Apple Public Source License 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "APSL-1.2": License(
        id="APSL-1.2",
        name="Apple Public Source License 1.2",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "APSL-2.0": License(
        id="APSL-2.0",
        name="Apple Public Source License 2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "Arphic-1999": License(
        id="Arphic-1999",
        name="Arphic Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Artistic-1.0": License(
        id="Artistic-1.0",
        name="Artistic License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Artistic-1.0-cl8": License(
        id="Artistic-1.0-cl8",
        name="Artistic License 1.0 w/clause 8",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Artistic-1.0-Perl": License(
        id="Artistic-1.0-Perl",
        name="Artistic License 1.0 (Perl)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Artistic-2.0": License(
        id="Artistic-2.0",
        name="Artistic License 2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "ASWF-Digital-Assets-1.0": License(
        id="ASWF-Digital-Assets-1.0",
        name="ASWF Digital Assets License version 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ASWF-Digital-Assets-1.1": License(
        id="ASWF-Digital-Assets-1.1",
        name="ASWF Digital Assets License 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Baekmuk": License(
        id="Baekmuk",
        name="Baekmuk License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Bahyph": License(
        id="Bahyph",
        name="Bahyph License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Barr": License(
        id="Barr",
        name="Barr License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "bcrypt-Solar-Designer": License(
        id="bcrypt-Solar-Designer",
        name="bcrypt Solar Designer License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Beerware": License(
        id="Beerware",
        name="Beerware License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Bitstream-Charter": License(
        id="Bitstream-Charter",
        name="Bitstream Charter Font License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Bitstream-Vera": License(
        id="Bitstream-Vera",
        name="Bitstream Vera Font License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BitTorrent-1.0": License(
        id="BitTorrent-1.0",
        name="BitTorrent Open Source License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BitTorrent-1.1": License(
        id="BitTorrent-1.1",
        name="BitTorrent Open Source License v1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "blessing": License(
        id="blessing",
        name="SQLite Blessing",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BlueOak-1.0.0": License(
        id="BlueOak-1.0.0",
        name="Blue Oak Model License 1.0.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Boehm-GC": License(
        id="Boehm-GC",
        name="Boehm-Demers-Weiser GC License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Borceux": License(
        id="Borceux",
        name="Borceux license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Brian-Gladman-2-Clause": License(
        id="Brian-Gladman-2-Clause",
        name="Brian Gladman 2-Clause License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Brian-Gladman-3-Clause": License(
        id="Brian-Gladman-3-Clause",
        name="Brian Gladman 3-Clause License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-1-Clause": License(
        id="BSD-1-Clause",
        name="BSD 1-Clause License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "BSD-2-Clause": License(
        id="BSD-2-Clause",
        name='BSD 2-Clause "Simplified" License',
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "BSD-2-Clause-Darwin": License(
        id="BSD-2-Clause-Darwin",
        name="BSD 2-Clause - Ian Darwin variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-2-Clause-FreeBSD": License(
        id="BSD-2-Clause-FreeBSD",
        name="BSD 2-Clause FreeBSD License",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=False,
    ),
    "BSD-2-Clause-NetBSD": License(
        id="BSD-2-Clause-NetBSD",
        name="BSD 2-Clause NetBSD License",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=False,
    ),
    "BSD-2-Clause-Patent": License(
        id="BSD-2-Clause-Patent",
        name="BSD-2-Clause Plus Patent License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "BSD-2-Clause-Views": License(
        id="BSD-2-Clause-Views",
        name="BSD 2-Clause with views sentence",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause": License(
        id="BSD-3-Clause",
        name='BSD 3-Clause "New" or "Revised" License',
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "BSD-3-Clause-acpica": License(
        id="BSD-3-Clause-acpica",
        name="BSD 3-Clause acpica variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-Attribution": License(
        id="BSD-3-Clause-Attribution",
        name="BSD with attribution",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-Clear": License(
        id="BSD-3-Clause-Clear",
        name="BSD 3-Clause Clear License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "BSD-3-Clause-flex": License(
        id="BSD-3-Clause-flex",
        name="BSD 3-Clause Flex variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-HP": License(
        id="BSD-3-Clause-HP",
        name="Hewlett-Packard BSD variant license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-LBNL": License(
        id="BSD-3-Clause-LBNL",
        name="Lawrence Berkeley National Labs BSD variant license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "BSD-3-Clause-Modification": License(
        id="BSD-3-Clause-Modification",
        name="BSD 3-Clause Modification",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-No-Military-License": License(
        id="BSD-3-Clause-No-Military-License",
        name="BSD 3-Clause No Military License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-No-Nuclear-License": License(
        id="BSD-3-Clause-No-Nuclear-License",
        name="BSD 3-Clause No Nuclear License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-No-Nuclear-License-2014": License(
        id="BSD-3-Clause-No-Nuclear-License-2014",
        name="BSD 3-Clause No Nuclear License 2014",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-No-Nuclear-Warranty": License(
        id="BSD-3-Clause-No-Nuclear-Warranty",
        name="BSD 3-Clause No Nuclear Warranty",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-Open-MPI": License(
        id="BSD-3-Clause-Open-MPI",
        name="BSD 3-Clause Open MPI variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-3-Clause-Sun": License(
        id="BSD-3-Clause-Sun",
        name="BSD 3-Clause Sun Microsystems",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-4-Clause": License(
        id="BSD-4-Clause",
        name='BSD 4-Clause "Original" or "Old" License',
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "BSD-4-Clause-Shortened": License(
        id="BSD-4-Clause-Shortened",
        name="BSD 4 Clause Shortened",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-4-Clause-UC": License(
        id="BSD-4-Clause-UC",
        name="BSD-4-Clause (University of California-Specific)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-4.3RENO": License(
        id="BSD-4.3RENO",
        name="BSD 4.3 RENO License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-4.3TAHOE": License(
        id="BSD-4.3TAHOE",
        name="BSD 4.3 TAHOE License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-Advertising-Acknowledgement": License(
        id="BSD-Advertising-Acknowledgement",
        name="BSD Advertising Acknowledgement License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-Attribution-HPND-disclaimer": License(
        id="BSD-Attribution-HPND-disclaimer",
        name="BSD with Attribution and HPND disclaimer",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-Inferno-Nettverk": License(
        id="BSD-Inferno-Nettverk",
        name="BSD-Inferno-Nettverk",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-Protection": License(
        id="BSD-Protection",
        name="BSD Protection License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-Source-beginning-file": License(
        id="BSD-Source-beginning-file",
        name="BSD Source Code Attribution - beginning of file variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-Source-Code": License(
        id="BSD-Source-Code",
        name="BSD Source Code Attribution",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-Systemics": License(
        id="BSD-Systemics",
        name="Systemics BSD variant license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSD-Systemics-W3Works": License(
        id="BSD-Systemics-W3Works",
        name="Systemics W3Works BSD variant license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "BSL-1.0": License(
        id="BSL-1.0",
        name="Boost Software License 1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "BUSL-1.1": License(
        id="BUSL-1.1",
        name="Business Source License 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "bzip2-1.0.5": License(
        id="bzip2-1.0.5",
        name="bzip2 and libbzip2 License v1.0.5",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=False,
    ),
    "bzip2-1.0.6": License(
        id="bzip2-1.0.6",
        name="bzip2 and libbzip2 License v1.0.6",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "C-UDA-1.0": License(
        id="C-UDA-1.0",
        name="Computational Use of Data Agreement v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CAL-1.0": License(
        id="CAL-1.0",
        name="Cryptographic Autonomy License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "CAL-1.0-Combined-Work-Exception": License(
        id="CAL-1.0-Combined-Work-Exception",
        name="Cryptographic Autonomy License 1.0 (Combined Work Exception)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Caldera": License(
        id="Caldera",
        name="Caldera License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Caldera-no-preamble": License(
        id="Caldera-no-preamble",
        name="Caldera License (without preamble)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CATOSL-1.1": License(
        id="CATOSL-1.1",
        name="Computer Associates Trusted Open Source License 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "CC-BY-1.0": License(
        id="CC-BY-1.0",
        name="Creative Commons Attribution 1.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-2.0": License(
        id="CC-BY-2.0",
        name="Creative Commons Attribution 2.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-2.5": License(
        id="CC-BY-2.5",
        name="Creative Commons Attribution 2.5 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-2.5-AU": License(
        id="CC-BY-2.5-AU",
        name="Creative Commons Attribution 2.5 Australia",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-3.0": License(
        id="CC-BY-3.0",
        name="Creative Commons Attribution 3.0 Unported",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-3.0-AT": License(
        id="CC-BY-3.0-AT",
        name="Creative Commons Attribution 3.0 Austria",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-3.0-AU": License(
        id="CC-BY-3.0-AU",
        name="Creative Commons Attribution 3.0 Australia",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-3.0-DE": License(
        id="CC-BY-3.0-DE",
        name="Creative Commons Attribution 3.0 Germany",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-3.0-IGO": License(
        id="CC-BY-3.0-IGO",
        name="Creative Commons Attribution 3.0 IGO",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-3.0-NL": License(
        id="CC-BY-3.0-NL",
        name="Creative Commons Attribution 3.0 Netherlands",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-3.0-US": License(
        id="CC-BY-3.0-US",
        name="Creative Commons Attribution 3.0 United States",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-4.0": License(
        id="CC-BY-4.0",
        name="Creative Commons Attribution 4.0 International",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "CC-BY-NC-1.0": License(
        id="CC-BY-NC-1.0",
        name="Creative Commons Attribution Non Commercial 1.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-2.0": License(
        id="CC-BY-NC-2.0",
        name="Creative Commons Attribution Non Commercial 2.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-2.5": License(
        id="CC-BY-NC-2.5",
        name="Creative Commons Attribution Non Commercial 2.5 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-3.0": License(
        id="CC-BY-NC-3.0",
        name="Creative Commons Attribution Non Commercial 3.0 Unported",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-3.0-DE": License(
        id="CC-BY-NC-3.0-DE",
        name="Creative Commons Attribution Non Commercial 3.0 Germany",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-4.0": License(
        id="CC-BY-NC-4.0",
        name="Creative Commons Attribution Non Commercial 4.0 International",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-ND-1.0": License(
        id="CC-BY-NC-ND-1.0",
        name="Creative Commons Attribution Non Commercial No Derivatives 1.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-ND-2.0": License(
        id="CC-BY-NC-ND-2.0",
        name="Creative Commons Attribution Non Commercial No Derivatives 2.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-ND-2.5": License(
        id="CC-BY-NC-ND-2.5",
        name="Creative Commons Attribution Non Commercial No Derivatives 2.5 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-ND-3.0": License(
        id="CC-BY-NC-ND-3.0",
        name="Creative Commons Attribution Non Commercial No Derivatives 3.0 Unported",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-ND-3.0-DE": License(
        id="CC-BY-NC-ND-3.0-DE",
        name="Creative Commons Attribution Non Commercial No Derivatives 3.0 Germany",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-ND-3.0-IGO": License(
        id="CC-BY-NC-ND-3.0-IGO",
        name="Creative Commons Attribution Non Commercial No Derivatives 3.0 IGO",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-ND-4.0": License(
        id="CC-BY-NC-ND-4.0",
        name="Creative Commons Attribution Non Commercial No Derivatives 4.0 International",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-1.0": License(
        id="CC-BY-NC-SA-1.0",
        name="Creative Commons Attribution Non Commercial Share Alike 1.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-2.0": License(
        id="CC-BY-NC-SA-2.0",
        name="Creative Commons Attribution Non Commercial Share Alike 2.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-2.0-DE": License(
        id="CC-BY-NC-SA-2.0-DE",
        name="Creative Commons Attribution Non Commercial Share Alike 2.0 Germany",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-2.0-FR": License(
        id="CC-BY-NC-SA-2.0-FR",
        name="Creative Commons Attribution-NonCommercial-ShareAlike 2.0 France",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-2.0-UK": License(
        id="CC-BY-NC-SA-2.0-UK",
        name="Creative Commons Attribution Non Commercial Share Alike 2.0 England and Wales",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-2.5": License(
        id="CC-BY-NC-SA-2.5",
        name="Creative Commons Attribution Non Commercial Share Alike 2.5 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-3.0": License(
        id="CC-BY-NC-SA-3.0",
        name="Creative Commons Attribution Non Commercial Share Alike 3.0 Unported",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-3.0-DE": License(
        id="CC-BY-NC-SA-3.0-DE",
        name="Creative Commons Attribution Non Commercial Share Alike 3.0 Germany",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-3.0-IGO": License(
        id="CC-BY-NC-SA-3.0-IGO",
        name="Creative Commons Attribution Non Commercial Share Alike 3.0 IGO",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-NC-SA-4.0": License(
        id="CC-BY-NC-SA-4.0",
        name="Creative Commons Attribution Non Commercial Share Alike 4.0 International",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-ND-1.0": License(
        id="CC-BY-ND-1.0",
        name="Creative Commons Attribution No Derivatives 1.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-ND-2.0": License(
        id="CC-BY-ND-2.0",
        name="Creative Commons Attribution No Derivatives 2.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-ND-2.5": License(
        id="CC-BY-ND-2.5",
        name="Creative Commons Attribution No Derivatives 2.5 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-ND-3.0": License(
        id="CC-BY-ND-3.0",
        name="Creative Commons Attribution No Derivatives 3.0 Unported",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-ND-3.0-DE": License(
        id="CC-BY-ND-3.0-DE",
        name="Creative Commons Attribution No Derivatives 3.0 Germany",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-ND-4.0": License(
        id="CC-BY-ND-4.0",
        name="Creative Commons Attribution No Derivatives 4.0 International",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-1.0": License(
        id="CC-BY-SA-1.0",
        name="Creative Commons Attribution Share Alike 1.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-2.0": License(
        id="CC-BY-SA-2.0",
        name="Creative Commons Attribution Share Alike 2.0 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-2.0-UK": License(
        id="CC-BY-SA-2.0-UK",
        name="Creative Commons Attribution Share Alike 2.0 England and Wales",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-2.1-JP": License(
        id="CC-BY-SA-2.1-JP",
        name="Creative Commons Attribution Share Alike 2.1 Japan",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-2.5": License(
        id="CC-BY-SA-2.5",
        name="Creative Commons Attribution Share Alike 2.5 Generic",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-3.0": License(
        id="CC-BY-SA-3.0",
        name="Creative Commons Attribution Share Alike 3.0 Unported",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-3.0-AT": License(
        id="CC-BY-SA-3.0-AT",
        name="Creative Commons Attribution Share Alike 3.0 Austria",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-3.0-DE": License(
        id="CC-BY-SA-3.0-DE",
        name="Creative Commons Attribution Share Alike 3.0 Germany",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-3.0-IGO": License(
        id="CC-BY-SA-3.0-IGO",
        name="Creative Commons Attribution-ShareAlike 3.0 IGO",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC-BY-SA-4.0": License(
        id="CC-BY-SA-4.0",
        name="Creative Commons Attribution Share Alike 4.0 International",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "CC-PDDC": License(
        id="CC-PDDC",
        name="Creative Commons Public Domain Dedication and Certification",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CC0-1.0": License(
        id="CC0-1.0",
        name="Creative Commons Zero v1.0 Universal",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "CDDL-1.0": License(
        id="CDDL-1.0",
        name="Common Development and Distribution License 1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "CDDL-1.1": License(
        id="CDDL-1.1",
        name="Common Development and Distribution License 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CDL-1.0": License(
        id="CDL-1.0",
        name="Common Documentation License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CDLA-Permissive-1.0": License(
        id="CDLA-Permissive-1.0",
        name="Community Data License Agreement Permissive 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CDLA-Permissive-2.0": License(
        id="CDLA-Permissive-2.0",
        name="Community Data License Agreement Permissive 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CDLA-Sharing-1.0": License(
        id="CDLA-Sharing-1.0",
        name="Community Data License Agreement Sharing 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CECILL-1.0": License(
        id="CECILL-1.0",
        name="CeCILL Free Software License Agreement v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CECILL-1.1": License(
        id="CECILL-1.1",
        name="CeCILL Free Software License Agreement v1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CECILL-2.0": License(
        id="CECILL-2.0",
        name="CeCILL Free Software License Agreement v2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "CECILL-2.1": License(
        id="CECILL-2.1",
        name="CeCILL Free Software License Agreement v2.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "CECILL-B": License(
        id="CECILL-B",
        name="CeCILL-B Free Software License Agreement",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "CECILL-C": License(
        id="CECILL-C",
        name="CeCILL-C Free Software License Agreement",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "CERN-OHL-1.1": License(
        id="CERN-OHL-1.1",
        name="CERN Open Hardware Licence v1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CERN-OHL-1.2": License(
        id="CERN-OHL-1.2",
        name="CERN Open Hardware Licence v1.2",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CERN-OHL-P-2.0": License(
        id="CERN-OHL-P-2.0",
        name="CERN Open Hardware Licence Version 2 - Permissive",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "CERN-OHL-S-2.0": License(
        id="CERN-OHL-S-2.0",
        name="CERN Open Hardware Licence Version 2 - Strongly Reciprocal",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "CERN-OHL-W-2.0": License(
        id="CERN-OHL-W-2.0",
        name="CERN Open Hardware Licence Version 2 - Weakly Reciprocal",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "CFITSIO": License(
        id="CFITSIO",
        name="CFITSIO License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "check-cvs": License(
        id="check-cvs",
        name="check-cvs License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "checkmk": License(
        id="checkmk",
        name="Checkmk License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ClArtistic": License(
        id="ClArtistic",
        name="Clarified Artistic License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Clips": License(
        id="Clips",
        name="Clips License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CMU-Mach": License(
        id="CMU-Mach",
        name="CMU Mach License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CMU-Mach-nodoc": License(
        id="CMU-Mach-nodoc",
        name="CMU    Mach - no notices-in-documentation variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CNRI-Jython": License(
        id="CNRI-Jython",
        name="CNRI Jython License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CNRI-Python": License(
        id="CNRI-Python",
        name="CNRI Python License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "CNRI-Python-GPL-Compatible": License(
        id="CNRI-Python-GPL-Compatible",
        name="CNRI Python Open Source GPL Compatible License Agreement",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "COIL-1.0": License(
        id="COIL-1.0",
        name="Copyfree Open Innovation License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Community-Spec-1.0": License(
        id="Community-Spec-1.0",
        name="Community Specification License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Condor-1.1": License(
        id="Condor-1.1",
        name="Condor Public License v1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "copyleft-next-0.3.0": License(
        id="copyleft-next-0.3.0",
        name="copyleft-next 0.3.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "copyleft-next-0.3.1": License(
        id="copyleft-next-0.3.1",
        name="copyleft-next 0.3.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Cornell-Lossless-JPEG": License(
        id="Cornell-Lossless-JPEG",
        name="Cornell Lossless JPEG License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CPAL-1.0": License(
        id="CPAL-1.0",
        name="Common Public Attribution License 1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "CPL-1.0": License(
        id="CPL-1.0",
        name="Common Public License 1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "CPOL-1.02": License(
        id="CPOL-1.02",
        name="Code Project Open License 1.02",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Cronyx": License(
        id="Cronyx",
        name="Cronyx License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Crossword": License(
        id="Crossword",
        name="Crossword License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CrystalStacker": License(
        id="CrystalStacker",
        name="CrystalStacker License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "CUA-OPL-1.0": License(
        id="CUA-OPL-1.0",
        name="CUA Office Public License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Cube": License(
        id="Cube",
        name="Cube License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "curl": License(
        id="curl",
        name="curl License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "D-FSL-1.0": License(
        id="D-FSL-1.0",
        name="Deutsche Freie Software Lizenz",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "DEC-3-Clause": License(
        id="DEC-3-Clause",
        name="DEC 3-Clause License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "diffmark": License(
        id="diffmark",
        name="diffmark license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "DL-DE-BY-2.0": License(
        id="DL-DE-BY-2.0",
        name="Data licence Germany – attribution – version 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "DL-DE-ZERO-2.0": License(
        id="DL-DE-ZERO-2.0",
        name="Data licence Germany – zero – version 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "DOC": License(
        id="DOC",
        name="DOC License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Dotseqn": License(
        id="Dotseqn",
        name="Dotseqn License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "DRL-1.0": License(
        id="DRL-1.0",
        name="Detection Rule License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "DRL-1.1": License(
        id="DRL-1.1",
        name="Detection Rule License 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "DSDP": License(
        id="DSDP",
        name="DSDP License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "dtoa": License(
        id="dtoa",
        name="David M. Gay dtoa License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "dvipdfm": License(
        id="dvipdfm",
        name="dvipdfm License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ECL-1.0": License(
        id="ECL-1.0",
        name="Educational Community License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "ECL-2.0": License(
        id="ECL-2.0",
        name="Educational Community License v2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "eCos-2.0": License(
        id="eCos-2.0",
        name="eCos license version 2.0",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=False,
    ),
    "EFL-1.0": License(
        id="EFL-1.0",
        name="Eiffel Forum License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "EFL-2.0": License(
        id="EFL-2.0",
        name="Eiffel Forum License v2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "eGenix": License(
        id="eGenix",
        name="eGenix.com Public License 1.1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Elastic-2.0": License(
        id="Elastic-2.0",
        name="Elastic License 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Entessa": License(
        id="Entessa",
        name="Entessa Public License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "EPICS": License(
        id="EPICS",
        name="EPICS Open License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "EPL-1.0": License(
        id="EPL-1.0",
        name="Eclipse Public License 1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "EPL-2.0": License(
        id="EPL-2.0",
        name="Eclipse Public License 2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "ErlPL-1.1": License(
        id="ErlPL-1.1",
        name="Erlang Public License v1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "etalab-2.0": License(
        id="etalab-2.0",
        name="Etalab Open License 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "EUDatagrid": License(
        id="EUDatagrid",
        name="EU DataGrid Software License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "EUPL-1.0": License(
        id="EUPL-1.0",
        name="European Union Public License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "EUPL-1.1": License(
        id="EUPL-1.1",
        name="European Union Public License 1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "EUPL-1.2": License(
        id="EUPL-1.2",
        name="European Union Public License 1.2",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "Eurosym": License(
        id="Eurosym",
        name="Eurosym License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Fair": License(
        id="Fair",
        name="Fair License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "FBM": License(
        id="FBM",
        name="Fuzzy Bitmap License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "FDK-AAC": License(
        id="FDK-AAC",
        name="Fraunhofer FDK AAC Codec Library",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Ferguson-Twofish": License(
        id="Ferguson-Twofish",
        name="Ferguson Twofish License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Frameworx-1.0": License(
        id="Frameworx-1.0",
        name="Frameworx Open License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "FreeBSD-DOC": License(
        id="FreeBSD-DOC",
        name="FreeBSD Documentation License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "FreeImage": License(
        id="FreeImage",
        name="FreeImage Public License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "FSFAP": License(
        id="FSFAP",
        name="FSF All Permissive License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "FSFAP-no-warranty-disclaimer": License(
        id="FSFAP-no-warranty-disclaimer",
        name="FSF All Permissive License (without Warranty)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "FSFUL": License(
        id="FSFUL",
        name="FSF Unlimited License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "FSFULLR": License(
        id="FSFULLR",
        name="FSF Unlimited License (with License Retention)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "FSFULLRWD": License(
        id="FSFULLRWD",
        name="FSF Unlimited License (With License Retention and Warranty Disclaimer)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "FTL": License(
        id="FTL",
        name="Freetype Project License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Furuseth": License(
        id="Furuseth",
        name="Furuseth License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "fwlw": License(
        id="fwlw",
        name="fwlw License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GCR-docs": License(
        id="GCR-docs",
        name="Gnome GCR Documentation License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GD": License(
        id="GD",
        name="GD License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.1": License(
        id="GFDL-1.1",
        name="GNU Free Documentation License v1.1",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=False,
    ),
    "GFDL-1.1-invariants-only": License(
        id="GFDL-1.1-invariants-only",
        name="GNU Free Documentation License v1.1 only - invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.1-invariants-or-later": License(
        id="GFDL-1.1-invariants-or-later",
        name="GNU Free Documentation License v1.1 or later - invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.1-no-invariants-only": License(
        id="GFDL-1.1-no-invariants-only",
        name="GNU Free Documentation License v1.1 only - no invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.1-no-invariants-or-later": License(
        id="GFDL-1.1-no-invariants-or-later",
        name="GNU Free Documentation License v1.1 or later - no invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.1-only": License(
        id="GFDL-1.1-only",
        name="GNU Free Documentation License v1.1 only",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "GFDL-1.1-or-later": License(
        id="GFDL-1.1-or-later",
        name="GNU Free Documentation License v1.1 or later",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "GFDL-1.2": License(
        id="GFDL-1.2",
        name="GNU Free Documentation License v1.2",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=False,
    ),
    "GFDL-1.2-invariants-only": License(
        id="GFDL-1.2-invariants-only",
        name="GNU Free Documentation License v1.2 only - invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.2-invariants-or-later": License(
        id="GFDL-1.2-invariants-or-later",
        name="GNU Free Documentation License v1.2 or later - invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.2-no-invariants-only": License(
        id="GFDL-1.2-no-invariants-only",
        name="GNU Free Documentation License v1.2 only - no invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.2-no-invariants-or-later": License(
        id="GFDL-1.2-no-invariants-or-later",
        name="GNU Free Documentation License v1.2 or later - no invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.2-only": License(
        id="GFDL-1.2-only",
        name="GNU Free Documentation License v1.2 only",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "GFDL-1.2-or-later": License(
        id="GFDL-1.2-or-later",
        name="GNU Free Documentation License v1.2 or later",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "GFDL-1.3": License(
        id="GFDL-1.3",
        name="GNU Free Documentation License v1.3",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=False,
    ),
    "GFDL-1.3-invariants-only": License(
        id="GFDL-1.3-invariants-only",
        name="GNU Free Documentation License v1.3 only - invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.3-invariants-or-later": License(
        id="GFDL-1.3-invariants-or-later",
        name="GNU Free Documentation License v1.3 or later - invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.3-no-invariants-only": License(
        id="GFDL-1.3-no-invariants-only",
        name="GNU Free Documentation License v1.3 only - no invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.3-no-invariants-or-later": License(
        id="GFDL-1.3-no-invariants-or-later",
        name="GNU Free Documentation License v1.3 or later - no invariants",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GFDL-1.3-only": License(
        id="GFDL-1.3-only",
        name="GNU Free Documentation License v1.3 only",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "GFDL-1.3-or-later": License(
        id="GFDL-1.3-or-later",
        name="GNU Free Documentation License v1.3 or later",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Giftware": License(
        id="Giftware",
        name="Giftware License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GL2PS": License(
        id="GL2PS",
        name="GL2PS License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Glide": License(
        id="Glide",
        name="3dfx Glide License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Glulxe": License(
        id="Glulxe",
        name="Glulxe License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GLWTPL": License(
        id="GLWTPL",
        name="Good Luck With That Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "gnuplot": License(
        id="gnuplot",
        name="gnuplot License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "GPL-1.0": License(
        id="GPL-1.0",
        name="GNU General Public License v1.0 only",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-1.0+": License(
        id="GPL-1.0+",
        name="GNU General Public License v1.0 or later",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-1.0-only": License(
        id="GPL-1.0-only",
        name="GNU General Public License v1.0 only",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-1.0-or-later": License(
        id="GPL-1.0-or-later",
        name="GNU General Public License v1.0 or later",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-2.0": License(
        id="GPL-2.0",
        name="GNU General Public License v2.0 only",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=True,
    ),
    "GPL-2.0+": License(
        id="GPL-2.0+",
        name="GNU General Public License v2.0 or later",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=True,
    ),
    "GPL-2.0-only": License(
        id="GPL-2.0-only",
        name="GNU General Public License v2.0 only",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "GPL-2.0-or-later": License(
        id="GPL-2.0-or-later",
        name="GNU General Public License v2.0 or later",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "GPL-2.0-with-autoconf-exception": License(
        id="GPL-2.0-with-autoconf-exception",
        name="GNU General Public License v2.0 w/Autoconf exception",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-2.0-with-bison-exception": License(
        id="GPL-2.0-with-bison-exception",
        name="GNU General Public License v2.0 w/Bison exception",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-2.0-with-classpath-exception": License(
        id="GPL-2.0-with-classpath-exception",
        name="GNU General Public License v2.0 w/Classpath exception",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-2.0-with-font-exception": License(
        id="GPL-2.0-with-font-exception",
        name="GNU General Public License v2.0 w/Font exception",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-2.0-with-GCC-exception": License(
        id="GPL-2.0-with-GCC-exception",
        name="GNU General Public License v2.0 w/GCC Runtime Library exception",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-3.0": License(
        id="GPL-3.0",
        name="GNU General Public License v3.0 only",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=True,
    ),
    "GPL-3.0+": License(
        id="GPL-3.0+",
        name="GNU General Public License v3.0 or later",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=True,
    ),
    "GPL-3.0-only": License(
        id="GPL-3.0-only",
        name="GNU General Public License v3.0 only",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "GPL-3.0-or-later": License(
        id="GPL-3.0-or-later",
        name="GNU General Public License v3.0 or later",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "GPL-3.0-with-autoconf-exception": License(
        id="GPL-3.0-with-autoconf-exception",
        name="GNU General Public License v3.0 w/Autoconf exception",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=False,
    ),
    "GPL-3.0-with-GCC-exception": License(
        id="GPL-3.0-with-GCC-exception",
        name="GNU General Public License v3.0 w/GCC Runtime Library exception",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Graphics-Gems": License(
        id="Graphics-Gems",
        name="Graphics Gems License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "gSOAP-1.3b": License(
        id="gSOAP-1.3b",
        name="gSOAP Public License v1.3b",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "gtkbook": License(
        id="gtkbook",
        name="gtkbook License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HaskellReport": License(
        id="HaskellReport",
        name="Haskell Language Report License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "hdparm": License(
        id="hdparm",
        name="hdparm License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Hippocratic-2.1": License(
        id="Hippocratic-2.1",
        name="Hippocratic License 2.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HP-1986": License(
        id="HP-1986",
        name="Hewlett-Packard 1986 License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HP-1989": License(
        id="HP-1989",
        name="Hewlett-Packard 1989 License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND": License(
        id="HPND",
        name="Historical Permission Notice and Disclaimer",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "HPND-DEC": License(
        id="HPND-DEC",
        name="Historical Permission Notice and Disclaimer - DEC variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-doc": License(
        id="HPND-doc",
        name="Historical Permission Notice and Disclaimer - documentation variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-doc-sell": License(
        id="HPND-doc-sell",
        name="Historical Permission Notice and Disclaimer - documentation sell variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-export-US": License(
        id="HPND-export-US",
        name="HPND with US Government export control warning",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-export-US-modify": License(
        id="HPND-export-US-modify",
        name="HPND with US Government export control warning and modification rqmt",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-Fenneberg-Livingston": License(
        id="HPND-Fenneberg-Livingston",
        name="Historical Permission Notice and Disclaimer - Fenneberg-Livingston variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-INRIA-IMAG": License(
        id="HPND-INRIA-IMAG",
        name="Historical Permission Notice and Disclaimer    - INRIA-IMAG variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-Kevlin-Henney": License(
        id="HPND-Kevlin-Henney",
        name="Historical Permission Notice and Disclaimer - Kevlin Henney variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-Markus-Kuhn": License(
        id="HPND-Markus-Kuhn",
        name="Historical Permission Notice and Disclaimer - Markus Kuhn variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-MIT-disclaimer": License(
        id="HPND-MIT-disclaimer",
        name="Historical Permission Notice and Disclaimer with MIT disclaimer",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-Pbmplus": License(
        id="HPND-Pbmplus",
        name="Historical Permission Notice and Disclaimer - Pbmplus variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-sell-MIT-disclaimer-xserver": License(
        id="HPND-sell-MIT-disclaimer-xserver",
        name="Historical Permission Notice and Disclaimer - sell xserver variant with MIT disclaimer",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-sell-regexpr": License(
        id="HPND-sell-regexpr",
        name="Historical Permission Notice and Disclaimer - sell regexpr variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-sell-variant": License(
        id="HPND-sell-variant",
        name="Historical Permission Notice and Disclaimer - sell variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-sell-variant-MIT-disclaimer": License(
        id="HPND-sell-variant-MIT-disclaimer",
        name="HPND sell variant with MIT disclaimer",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HPND-UC": License(
        id="HPND-UC",
        name="Historical Permission Notice and Disclaimer - University of California variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "HTMLTIDY": License(
        id="HTMLTIDY",
        name="HTML Tidy License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "IBM-pibs": License(
        id="IBM-pibs",
        name="IBM PowerPC Initialization and Boot Software",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ICU": License(
        id="ICU",
        name="ICU License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "IEC-Code-Components-EULA": License(
        id="IEC-Code-Components-EULA",
        name="IEC    Code Components End-user licence agreement",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "IJG": License(
        id="IJG",
        name="Independent JPEG Group License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "IJG-short": License(
        id="IJG-short",
        name="Independent JPEG Group License - short",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ImageMagick": License(
        id="ImageMagick",
        name="ImageMagick License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "iMatix": License(
        id="iMatix",
        name="iMatix Standard Function Library Agreement",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Imlib2": License(
        id="Imlib2",
        name="Imlib2 License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Info-ZIP": License(
        id="Info-ZIP",
        name="Info-ZIP License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Inner-Net-2.0": License(
        id="Inner-Net-2.0",
        name="Inner Net License v2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Intel": License(
        id="Intel",
        name="Intel Open Source License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "Intel-ACPI": License(
        id="Intel-ACPI",
        name="Intel ACPI Software License Agreement",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Interbase-1.0": License(
        id="Interbase-1.0",
        name="Interbase Public License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "IPA": License(
        id="IPA",
        name="IPA Font License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "IPL-1.0": License(
        id="IPL-1.0",
        name="IBM Public License v1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "ISC": License(
        id="ISC",
        name="ISC License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "ISC-Veillard": License(
        id="ISC-Veillard",
        name="ISC Veillard variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Jam": License(
        id="Jam",
        name="Jam License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "JasPer-2.0": License(
        id="JasPer-2.0",
        name="JasPer License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "JPL-image": License(
        id="JPL-image",
        name="JPL Image Use Policy",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "JPNIC": License(
        id="JPNIC",
        name="Japan Network Information Center License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "JSON": License(
        id="JSON",
        name="JSON License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Kastrup": License(
        id="Kastrup",
        name="Kastrup License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Kazlib": License(
        id="Kazlib",
        name="Kazlib License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Knuth-CTAN": License(
        id="Knuth-CTAN",
        name="Knuth CTAN License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LAL-1.2": License(
        id="LAL-1.2",
        name="Licence Art Libre 1.2",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LAL-1.3": License(
        id="LAL-1.3",
        name="Licence Art Libre 1.3",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Latex2e": License(
        id="Latex2e",
        name="Latex2e License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Latex2e-translated-notice": License(
        id="Latex2e-translated-notice",
        name="Latex2e with translated notice permission",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Leptonica": License(
        id="Leptonica",
        name="Leptonica License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LGPL-2.0": License(
        id="LGPL-2.0",
        name="GNU Library General Public License v2 only",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=True,
    ),
    "LGPL-2.0+": License(
        id="LGPL-2.0+",
        name="GNU Library General Public License v2 or later",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=True,
    ),
    "LGPL-2.0-only": License(
        id="LGPL-2.0-only",
        name="GNU Library General Public License v2 only",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "LGPL-2.0-or-later": License(
        id="LGPL-2.0-or-later",
        name="GNU Library General Public License v2 or later",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "LGPL-2.1": License(
        id="LGPL-2.1",
        name="GNU Lesser General Public License v2.1 only",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=True,
    ),
    "LGPL-2.1+": License(
        id="LGPL-2.1+",
        name="GNU Lesser General Public License v2.1 or later",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=True,
    ),
    "LGPL-2.1-only": License(
        id="LGPL-2.1-only",
        name="GNU Lesser General Public License v2.1 only",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "LGPL-2.1-or-later": License(
        id="LGPL-2.1-or-later",
        name="GNU Lesser General Public License v2.1 or later",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "LGPL-3.0": License(
        id="LGPL-3.0",
        name="GNU Lesser General Public License v3.0 only",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=True,
    ),
    "LGPL-3.0+": License(
        id="LGPL-3.0+",
        name="GNU Lesser General Public License v3.0 or later",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=True,
    ),
    "LGPL-3.0-only": License(
        id="LGPL-3.0-only",
        name="GNU Lesser General Public License v3.0 only",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "LGPL-3.0-or-later": License(
        id="LGPL-3.0-or-later",
        name="GNU Lesser General Public License v3.0 or later",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "LGPLLR": License(
        id="LGPLLR",
        name="Lesser General Public License For Linguistic Resources",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Libpng": License(
        id="Libpng",
        name="libpng License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "libpng-2.0": License(
        id="libpng-2.0",
        name="PNG Reference Library version 2",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "libselinux-1.0": License(
        id="libselinux-1.0",
        name="libselinux public domain notice",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "libtiff": License(
        id="libtiff",
        name="libtiff License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "libutil-David-Nugent": License(
        id="libutil-David-Nugent",
        name="libutil David Nugent License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LiLiQ-P-1.1": License(
        id="LiLiQ-P-1.1",
        name="Licence Libre du Québec – Permissive version 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "LiLiQ-R-1.1": License(
        id="LiLiQ-R-1.1",
        name="Licence Libre du Québec – Réciprocité version 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "LiLiQ-Rplus-1.1": License(
        id="LiLiQ-Rplus-1.1",
        name="Licence Libre du Québec – Réciprocité forte version 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Linux-man-pages-1-para": License(
        id="Linux-man-pages-1-para",
        name="Linux man-pages - 1 paragraph",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Linux-man-pages-copyleft": License(
        id="Linux-man-pages-copyleft",
        name="Linux man-pages Copyleft",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Linux-man-pages-copyleft-2-para": License(
        id="Linux-man-pages-copyleft-2-para",
        name="Linux man-pages Copyleft - 2 paragraphs",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Linux-man-pages-copyleft-var": License(
        id="Linux-man-pages-copyleft-var",
        name="Linux man-pages Copyleft Variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Linux-OpenIB": License(
        id="Linux-OpenIB",
        name="Linux Kernel Variant of OpenIB.org license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LOOP": License(
        id="LOOP",
        name="Common Lisp LOOP License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LPD-document": License(
        id="LPD-document",
        name="LPD Documentation License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LPL-1.0": License(
        id="LPL-1.0",
        name="Lucent Public License Version 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "LPL-1.02": License(
        id="LPL-1.02",
        name="Lucent Public License v1.02",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "LPPL-1.0": License(
        id="LPPL-1.0",
        name="LaTeX Project Public License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LPPL-1.1": License(
        id="LPPL-1.1",
        name="LaTeX Project Public License v1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LPPL-1.2": License(
        id="LPPL-1.2",
        name="LaTeX Project Public License v1.2",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "LPPL-1.3a": License(
        id="LPPL-1.3a",
        name="LaTeX Project Public License v1.3a",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "LPPL-1.3c": License(
        id="LPPL-1.3c",
        name="LaTeX Project Public License v1.3c",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "lsof": License(
        id="lsof",
        name="lsof License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Lucida-Bitmap-Fonts": License(
        id="Lucida-Bitmap-Fonts",
        name="Lucida Bitmap Fonts License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LZMA-SDK-9.11-to-9.20": License(
        id="LZMA-SDK-9.11-to-9.20",
        name="LZMA SDK License (versions 9.11 to 9.20)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "LZMA-SDK-9.22": License(
        id="LZMA-SDK-9.22",
        name="LZMA SDK License (versions 9.22 and beyond)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Mackerras-3-Clause": License(
        id="Mackerras-3-Clause",
        name="Mackerras 3-Clause License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Mackerras-3-Clause-acknowledgment": License(
        id="Mackerras-3-Clause-acknowledgment",
        name="Mackerras 3-Clause - acknowledgment variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "magaz": License(
        id="magaz",
        name="magaz License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "mailprio": License(
        id="mailprio",
        name="mailprio License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MakeIndex": License(
        id="MakeIndex",
        name="MakeIndex License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Martin-Birgmeier": License(
        id="Martin-Birgmeier",
        name="Martin Birgmeier License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "McPhee-slideshow": License(
        id="McPhee-slideshow",
        name="McPhee Slideshow License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "metamail": License(
        id="metamail",
        name="metamail License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Minpack": License(
        id="Minpack",
        name="Minpack License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MirOS": License(
        id="MirOS",
        name="The MirOS Licence",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "MIT": License(
        id="MIT",
        name="MIT License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "MIT-0": License(
        id="MIT-0",
        name="MIT No Attribution",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "MIT-advertising": License(
        id="MIT-advertising",
        name="Enlightenment License (e16)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MIT-CMU": License(
        id="MIT-CMU",
        name="CMU License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MIT-enna": License(
        id="MIT-enna",
        name="enna License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MIT-feh": License(
        id="MIT-feh",
        name="feh License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MIT-Festival": License(
        id="MIT-Festival",
        name="MIT Festival Variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MIT-Modern-Variant": License(
        id="MIT-Modern-Variant",
        name="MIT License Modern Variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "MIT-open-group": License(
        id="MIT-open-group",
        name="MIT Open Group variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MIT-testregex": License(
        id="MIT-testregex",
        name="MIT testregex Variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MIT-Wu": License(
        id="MIT-Wu",
        name="MIT Tom Wu Variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MITNFA": License(
        id="MITNFA",
        name="MIT +no-false-attribs license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MMIXware": License(
        id="MMIXware",
        name="MMIXware License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Motosoto": License(
        id="Motosoto",
        name="Motosoto License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "MPEG-SSG": License(
        id="MPEG-SSG",
        name="MPEG Software Simulation",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "mpi-permissive": License(
        id="mpi-permissive",
        name="mpi Permissive License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "mpich2": License(
        id="mpich2",
        name="mpich2 License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MPL-1.0": License(
        id="MPL-1.0",
        name="Mozilla Public License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "MPL-1.1": License(
        id="MPL-1.1",
        name="Mozilla Public License 1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "MPL-2.0": License(
        id="MPL-2.0",
        name="Mozilla Public License 2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "MPL-2.0-no-copyleft-exception": License(
        id="MPL-2.0-no-copyleft-exception",
        name="Mozilla Public License 2.0 (no copyleft exception)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "mplus": License(
        id="mplus",
        name="mplus Font License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MS-LPL": License(
        id="MS-LPL",
        name="Microsoft Limited Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MS-PL": License(
        id="MS-PL",
        name="Microsoft Public License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "MS-RL": License(
        id="MS-RL",
        name="Microsoft Reciprocal License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "MTLL": License(
        id="MTLL",
        name="Matrix Template Library License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MulanPSL-1.0": License(
        id="MulanPSL-1.0",
        name="Mulan Permissive Software License, Version 1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "MulanPSL-2.0": License(
        id="MulanPSL-2.0",
        name="Mulan Permissive Software License, Version 2",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Multics": License(
        id="Multics",
        name="Multics License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Mup": License(
        id="Mup",
        name="Mup License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NAIST-2003": License(
        id="NAIST-2003",
        name="Nara Institute of Science and Technology License (2003)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NASA-1.3": License(
        id="NASA-1.3",
        name="NASA Open Source Agreement 1.3",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Naumen": License(
        id="Naumen",
        name="Naumen Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "NBPL-1.0": License(
        id="NBPL-1.0",
        name="Net Boolean Public License v1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NCGL-UK-2.0": License(
        id="NCGL-UK-2.0",
        name="Non-Commercial Government Licence",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NCSA": License(
        id="NCSA",
        name="University of Illinois/NCSA Open Source License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "Net-SNMP": License(
        id="Net-SNMP",
        name="Net-SNMP License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NetCDF": License(
        id="NetCDF",
        name="NetCDF license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Newsletr": License(
        id="Newsletr",
        name="Newsletr License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NGPL": License(
        id="NGPL",
        name="Nethack General Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "NICTA-1.0": License(
        id="NICTA-1.0",
        name="NICTA Public Software License, Version 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NIST-PD": License(
        id="NIST-PD",
        name="NIST Public Domain Notice",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NIST-PD-fallback": License(
        id="NIST-PD-fallback",
        name="NIST Public Domain Notice with license fallback",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NIST-Software": License(
        id="NIST-Software",
        name="NIST Software License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NLOD-1.0": License(
        id="NLOD-1.0",
        name="Norwegian Licence for Open Government Data (NLOD) 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NLOD-2.0": License(
        id="NLOD-2.0",
        name="Norwegian Licence for Open Government Data (NLOD) 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NLPL": License(
        id="NLPL",
        name="No Limit Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Nokia": License(
        id="Nokia",
        name="Nokia Open Source License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "NOSL": License(
        id="NOSL",
        name="Netizen Open Source License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Noweb": License(
        id="Noweb",
        name="Noweb License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NPL-1.0": License(
        id="NPL-1.0",
        name="Netscape Public License v1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "NPL-1.1": License(
        id="NPL-1.1",
        name="Netscape Public License v1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "NPOSL-3.0": License(
        id="NPOSL-3.0",
        name="Non-Profit Open Software License 3.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "NRL": License(
        id="NRL",
        name="NRL License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "NTP": License(
        id="NTP",
        name="NTP License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "NTP-0": License(
        id="NTP-0",
        name="NTP No Attribution",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Nunit": License(
        id="Nunit",
        name="Nunit License",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=False,
    ),
    "O-UDA-1.0": License(
        id="O-UDA-1.0",
        name="Open Use of Data Agreement v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OCCT-PL": License(
        id="OCCT-PL",
        name="Open CASCADE Technology Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OCLC-2.0": License(
        id="OCLC-2.0",
        name="OCLC Research Public License 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "ODbL-1.0": License(
        id="ODbL-1.0",
        name="Open Data Commons Open Database License v1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "ODC-By-1.0": License(
        id="ODC-By-1.0",
        name="Open Data Commons Attribution License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OFFIS": License(
        id="OFFIS",
        name="OFFIS License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OFL-1.0": License(
        id="OFL-1.0",
        name="SIL Open Font License 1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "OFL-1.0-no-RFN": License(
        id="OFL-1.0-no-RFN",
        name="SIL Open Font License 1.0 with no Reserved Font Name",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OFL-1.0-RFN": License(
        id="OFL-1.0-RFN",
        name="SIL Open Font License 1.0 with Reserved Font Name",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OFL-1.1": License(
        id="OFL-1.1",
        name="SIL Open Font License 1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "OFL-1.1-no-RFN": License(
        id="OFL-1.1-no-RFN",
        name="SIL Open Font License 1.1 with no Reserved Font Name",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "OFL-1.1-RFN": License(
        id="OFL-1.1-RFN",
        name="SIL Open Font License 1.1 with Reserved Font Name",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "OGC-1.0": License(
        id="OGC-1.0",
        name="OGC Software License, Version 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OGDL-Taiwan-1.0": License(
        id="OGDL-Taiwan-1.0",
        name="Taiwan Open Government Data License, version 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OGL-Canada-2.0": License(
        id="OGL-Canada-2.0",
        name="Open Government Licence - Canada",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OGL-UK-1.0": License(
        id="OGL-UK-1.0",
        name="Open Government Licence v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OGL-UK-2.0": License(
        id="OGL-UK-2.0",
        name="Open Government Licence v2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OGL-UK-3.0": License(
        id="OGL-UK-3.0",
        name="Open Government Licence v3.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OGTSL": License(
        id="OGTSL",
        name="Open Group Test Suite License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "OLDAP-1.1": License(
        id="OLDAP-1.1",
        name="Open LDAP Public License v1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-1.2": License(
        id="OLDAP-1.2",
        name="Open LDAP Public License v1.2",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-1.3": License(
        id="OLDAP-1.3",
        name="Open LDAP Public License v1.3",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-1.4": License(
        id="OLDAP-1.4",
        name="Open LDAP Public License v1.4",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.0": License(
        id="OLDAP-2.0",
        name="Open LDAP Public License v2.0 (or possibly 2.0A and 2.0B)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.0.1": License(
        id="OLDAP-2.0.1",
        name="Open LDAP Public License v2.0.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.1": License(
        id="OLDAP-2.1",
        name="Open LDAP Public License v2.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.2": License(
        id="OLDAP-2.2",
        name="Open LDAP Public License v2.2",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.2.1": License(
        id="OLDAP-2.2.1",
        name="Open LDAP Public License v2.2.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.2.2": License(
        id="OLDAP-2.2.2",
        name="Open LDAP Public License 2.2.2",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.3": License(
        id="OLDAP-2.3",
        name="Open LDAP Public License v2.3",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "OLDAP-2.4": License(
        id="OLDAP-2.4",
        name="Open LDAP Public License v2.4",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.5": License(
        id="OLDAP-2.5",
        name="Open LDAP Public License v2.5",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.6": License(
        id="OLDAP-2.6",
        name="Open LDAP Public License v2.6",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OLDAP-2.7": License(
        id="OLDAP-2.7",
        name="Open LDAP Public License v2.7",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "OLDAP-2.8": License(
        id="OLDAP-2.8",
        name="Open LDAP Public License v2.8",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "OLFL-1.3": License(
        id="OLFL-1.3",
        name="Open Logistics Foundation License Version 1.3",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "OML": License(
        id="OML",
        name="Open Market License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OpenPBS-2.3": License(
        id="OpenPBS-2.3",
        name="OpenPBS v2.3 Software License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OpenSSL": License(
        id="OpenSSL",
        name="OpenSSL License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "OpenSSL-standalone": License(
        id="OpenSSL-standalone",
        name="OpenSSL License - standalone",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OpenVision": License(
        id="OpenVision",
        name="OpenVision License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OPL-1.0": License(
        id="OPL-1.0",
        name="Open Public License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OPL-UK-3.0": License(
        id="OPL-UK-3.0",
        name="United    Kingdom Open Parliament Licence v3.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OPUBL-1.0": License(
        id="OPUBL-1.0",
        name="Open Publication License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "OSET-PL-2.1": License(
        id="OSET-PL-2.1",
        name="OSET Public License version 2.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "OSL-1.0": License(
        id="OSL-1.0",
        name="Open Software License 1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "OSL-1.1": License(
        id="OSL-1.1",
        name="Open Software License 1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "OSL-2.0": License(
        id="OSL-2.0",
        name="Open Software License 2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "OSL-2.1": License(
        id="OSL-2.1",
        name="Open Software License 2.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "OSL-3.0": License(
        id="OSL-3.0",
        name="Open Software License 3.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "PADL": License(
        id="PADL",
        name="PADL License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Parity-6.0.0": License(
        id="Parity-6.0.0",
        name="The Parity Public License 6.0.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Parity-7.0.0": License(
        id="Parity-7.0.0",
        name="The Parity Public License 7.0.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "PDDL-1.0": License(
        id="PDDL-1.0",
        name="Open Data Commons Public Domain Dedication & License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "PHP-3.0": License(
        id="PHP-3.0",
        name="PHP License v3.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "PHP-3.01": License(
        id="PHP-3.01",
        name="PHP License v3.01",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "Pixar": License(
        id="Pixar",
        name="Pixar License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Plexus": License(
        id="Plexus",
        name="Plexus Classworlds License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "pnmstitch": License(
        id="pnmstitch",
        name="pnmstitch License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "PolyForm-Noncommercial-1.0.0": License(
        id="PolyForm-Noncommercial-1.0.0",
        name="PolyForm Noncommercial License 1.0.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "PolyForm-Small-Business-1.0.0": License(
        id="PolyForm-Small-Business-1.0.0",
        name="PolyForm Small Business License 1.0.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "PostgreSQL": License(
        id="PostgreSQL",
        name="PostgreSQL License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "PSF-2.0": License(
        id="PSF-2.0",
        name="Python Software Foundation License 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "psfrag": License(
        id="psfrag",
        name="psfrag License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "psutils": License(
        id="psutils",
        name="psutils License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Python-2.0": License(
        id="Python-2.0",
        name="Python License 2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "Python-2.0.1": License(
        id="Python-2.0.1",
        name="Python License 2.0.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "python-ldap": License(
        id="python-ldap",
        name="Python ldap License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Qhull": License(
        id="Qhull",
        name="Qhull License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "QPL-1.0": License(
        id="QPL-1.0",
        name="Q Public License 1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "QPL-1.0-INRIA-2004": License(
        id="QPL-1.0-INRIA-2004",
        name="Q Public License 1.0 - INRIA 2004 variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "radvd": License(
        id="radvd",
        name="radvd License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Rdisc": License(
        id="Rdisc",
        name="Rdisc License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "RHeCos-1.1": License(
        id="RHeCos-1.1",
        name="Red Hat eCos Public License v1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "RPL-1.1": License(
        id="RPL-1.1",
        name="Reciprocal Public License 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "RPL-1.5": License(
        id="RPL-1.5",
        name="Reciprocal Public License 1.5",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "RPSL-1.0": License(
        id="RPSL-1.0",
        name="RealNetworks Public Source License v1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "RSA-MD": License(
        id="RSA-MD",
        name="RSA Message-Digest License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "RSCPL": License(
        id="RSCPL",
        name="Ricoh Source Code Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Ruby": License(
        id="Ruby",
        name="Ruby License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "SAX-PD": License(
        id="SAX-PD",
        name="Sax Public Domain Notice",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SAX-PD-2.0": License(
        id="SAX-PD-2.0",
        name="Sax Public Domain Notice 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Saxpath": License(
        id="Saxpath",
        name="Saxpath License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SCEA": License(
        id="SCEA",
        name="SCEA Shared Source License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SchemeReport": License(
        id="SchemeReport",
        name="Scheme Language Report License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Sendmail": License(
        id="Sendmail",
        name="Sendmail License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Sendmail-8.23": License(
        id="Sendmail-8.23",
        name="Sendmail License 8.23",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SGI-B-1.0": License(
        id="SGI-B-1.0",
        name="SGI Free Software License B v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SGI-B-1.1": License(
        id="SGI-B-1.1",
        name="SGI Free Software License B v1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SGI-B-2.0": License(
        id="SGI-B-2.0",
        name="SGI Free Software License B v2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "SGI-OpenGL": License(
        id="SGI-OpenGL",
        name="SGI OpenGL License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SGP4": License(
        id="SGP4",
        name="SGP4 Permission Notice",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SHL-0.5": License(
        id="SHL-0.5",
        name="Solderpad Hardware License v0.5",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SHL-0.51": License(
        id="SHL-0.51",
        name="Solderpad Hardware License, Version 0.51",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SimPL-2.0": License(
        id="SimPL-2.0",
        name="Simple Public License 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "SISSL": License(
        id="SISSL",
        name="Sun Industry Standards Source License v1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "SISSL-1.2": License(
        id="SISSL-1.2",
        name="Sun Industry Standards Source License v1.2",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SL": License(
        id="SL",
        name="SL License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Sleepycat": License(
        id="Sleepycat",
        name="Sleepycat License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "SMLNJ": License(
        id="SMLNJ",
        name="Standard ML of New Jersey License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "SMPPL": License(
        id="SMPPL",
        name="Secure Messaging Protocol Public License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SNIA": License(
        id="SNIA",
        name="SNIA Public License 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "snprintf": License(
        id="snprintf",
        name="snprintf License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "softSurfer": License(
        id="softSurfer",
        name="softSurfer License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Soundex": License(
        id="Soundex",
        name="Soundex License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Spencer-86": License(
        id="Spencer-86",
        name="Spencer License 86",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Spencer-94": License(
        id="Spencer-94",
        name="Spencer License 94",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Spencer-99": License(
        id="Spencer-99",
        name="Spencer License 99",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SPL-1.0": License(
        id="SPL-1.0",
        name="Sun Public License v1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "ssh-keyscan": License(
        id="ssh-keyscan",
        name="ssh-keyscan License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SSH-OpenSSH": License(
        id="SSH-OpenSSH",
        name="SSH OpenSSH license",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SSH-short": License(
        id="SSH-short",
        name="SSH short notice",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SSLeay-standalone": License(
        id="SSLeay-standalone",
        name="SSLeay License - standalone",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SSPL-1.0": License(
        id="SSPL-1.0",
        name="Server Side Public License, v 1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "StandardML-NJ": License(
        id="StandardML-NJ",
        name="Standard ML of New Jersey License",
        deprecated_id=True,
        fsf_libre=True,
        osi_approved=False,
    ),
    "SugarCRM-1.1.3": License(
        id="SugarCRM-1.1.3",
        name="SugarCRM Public License v1.1.3",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Sun-PPP": License(
        id="Sun-PPP",
        name="Sun PPP License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SunPro": License(
        id="SunPro",
        name="SunPro License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "SWL": License(
        id="SWL",
        name="Scheme Widget Library (SWL) Software License Agreement",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "swrule": License(
        id="swrule",
        name="swrule License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Symlinks": License(
        id="Symlinks",
        name="Symlinks License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TAPR-OHL-1.0": License(
        id="TAPR-OHL-1.0",
        name="TAPR Open Hardware License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TCL": License(
        id="TCL",
        name="TCL/TK License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TCP-wrappers": License(
        id="TCP-wrappers",
        name="TCP Wrappers License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TermReadKey": License(
        id="TermReadKey",
        name="TermReadKey License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TGPPL-1.0": License(
        id="TGPPL-1.0",
        name="Transitive Grace Period Public Licence 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TMate": License(
        id="TMate",
        name="TMate Open Source License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TORQUE-1.1": License(
        id="TORQUE-1.1",
        name="TORQUE v2.5+ Software License v1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TOSL": License(
        id="TOSL",
        name="Trusster Open Source License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TPDL": License(
        id="TPDL",
        name="Time::ParseDate License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TPL-1.0": License(
        id="TPL-1.0",
        name="THOR Public License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TTWL": License(
        id="TTWL",
        name="Text-Tabs+Wrap License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TTYP0": License(
        id="TTYP0",
        name="TTYP0 License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TU-Berlin-1.0": License(
        id="TU-Berlin-1.0",
        name="Technische Universitaet Berlin License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "TU-Berlin-2.0": License(
        id="TU-Berlin-2.0",
        name="Technische Universitaet Berlin License 2.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "UCAR": License(
        id="UCAR",
        name="UCAR License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "UCL-1.0": License(
        id="UCL-1.0",
        name="Upstream Compatibility License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "ulem": License(
        id="ulem",
        name="ulem License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "UMich-Merit": License(
        id="UMich-Merit",
        name="Michigan/Merit Networks License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Unicode-3.0": License(
        id="Unicode-3.0",
        name="Unicode License v3",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Unicode-DFS-2015": License(
        id="Unicode-DFS-2015",
        name="Unicode License Agreement - Data Files and Software (2015)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Unicode-DFS-2016": License(
        id="Unicode-DFS-2016",
        name="Unicode License Agreement - Data Files and Software (2016)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Unicode-TOU": License(
        id="Unicode-TOU",
        name="Unicode Terms of Use",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "UnixCrypt": License(
        id="UnixCrypt",
        name="UnixCrypt License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Unlicense": License(
        id="Unlicense",
        name="The Unlicense",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "UPL-1.0": License(
        id="UPL-1.0",
        name="Universal Permissive License v1.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "URT-RLE": License(
        id="URT-RLE",
        name="Utah Raster Toolkit Run Length Encoded License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Vim": License(
        id="Vim",
        name="Vim License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "VOSTROM": License(
        id="VOSTROM",
        name="VOSTROM Public License for Open Source",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "VSL-1.0": License(
        id="VSL-1.0",
        name="Vovida Software License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "W3C": License(
        id="W3C",
        name="W3C Software Notice and License (2002-12-31)",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "W3C-19980720": License(
        id="W3C-19980720",
        name="W3C Software Notice and License (1998-07-20)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "W3C-20150513": License(
        id="W3C-20150513",
        name="W3C Software Notice and Document License (2015-05-13)",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "w3m": License(
        id="w3m",
        name="w3m License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Watcom-1.0": License(
        id="Watcom-1.0",
        name="Sybase Open Watcom Public License 1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "Widget-Workshop": License(
        id="Widget-Workshop",
        name="Widget Workshop License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Wsuipa": License(
        id="Wsuipa",
        name="Wsuipa License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "WTFPL": License(
        id="WTFPL",
        name="Do What The F*ck You Want To Public License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "wxWindows": License(
        id="wxWindows",
        name="wxWindows Library License",
        deprecated_id=True,
        fsf_libre=False,
        osi_approved=True,
    ),
    "X11": License(
        id="X11",
        name="X11 License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "X11-distribute-modifications-variant": License(
        id="X11-distribute-modifications-variant",
        name="X11 License Distribution Modification Variant",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Xdebug-1.03": License(
        id="Xdebug-1.03",
        name="Xdebug License v 1.03",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Xerox": License(
        id="Xerox",
        name="Xerox License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Xfig": License(
        id="Xfig",
        name="Xfig License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "XFree86-1.1": License(
        id="XFree86-1.1",
        name="XFree86 License 1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "xinetd": License(
        id="xinetd",
        name="xinetd License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "xkeyboard-config-Zinoviev": License(
        id="xkeyboard-config-Zinoviev",
        name="xkeyboard-config Zinoviev License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "xlock": License(
        id="xlock",
        name="xlock License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Xnet": License(
        id="Xnet",
        name="X.Net License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=True,
    ),
    "xpp": License(
        id="xpp",
        name="XPP License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "XSkat": License(
        id="XSkat",
        name="XSkat License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "YPL-1.0": License(
        id="YPL-1.0",
        name="Yahoo! Public License v1.0",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "YPL-1.1": License(
        id="YPL-1.1",
        name="Yahoo! Public License v1.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Zed": License(
        id="Zed",
        name="Zed License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Zeeff": License(
        id="Zeeff",
        name="Zeeff License",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Zend-2.0": License(
        id="Zend-2.0",
        name="Zend License v2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Zimbra-1.3": License(
        id="Zimbra-1.3",
        name="Zimbra Public License v1.3",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=False,
    ),
    "Zimbra-1.4": License(
        id="Zimbra-1.4",
        name="Zimbra Public License v1.4",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "Zlib": License(
        id="Zlib",
        name="zlib License",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "zlib-acknowledgement": License(
        id="zlib-acknowledgement",
        name="zlib/libpng License with Acknowledgement",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ZPL-1.1": License(
        id="ZPL-1.1",
        name="Zope Public License 1.1",
        deprecated_id=False,
        fsf_libre=False,
        osi_approved=False,
    ),
    "ZPL-2.0": License(
        id="ZPL-2.0",
        name="Zope Public License 2.0",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
    "ZPL-2.1": License(
        id="ZPL-2.1",
        name="Zope Public License 2.1",
        deprecated_id=False,
        fsf_libre=True,
        osi_approved=True,
    ),
}
